#
# Conditional build:
%if "%{pld_release}" == "ac"
%bcond_with	apidocs		# build and package API docs
%else
%bcond_without	apidocs		# do not build and package API docs
%endif

Summary:	Wrapper library for the Video Decode and Presentation API
Summary(pl.UTF-8):	Biblioteka pośrednia do API dekodowania i prezentacji video (Video Decode and Presentation API)
Name:		libvdpau
Version:	1.3
Release:	2
License:	MIT
Group:		Libraries
#Source0Download: https://gitlab.freedesktop.org/vdpau/libvdpau/tags
Source0:	https://gitlab.freedesktop.org/vdpau/libvdpau/-/archive/%{version}/libvdpau-%{version}.tar.bz2
# Source0-md5:	817e44068cbf92bfa93308daaeef2280
URL:		https://freedesktop.org/wiki/Software/VDPAU
%if %{with apidocs}
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	texlive-dvips
BuildRequires:	texlive-latex
%endif
BuildRequires:	libstdc++-devel
BuildRequires:	meson >= 0.41
BuildRequires:	ninja >= 1.5
BuildRequires:	pkgconfig
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.736
%if "%{pld_release}" == "ac"
BuildRequires:	XFree86-devel
%else
%{?with_apidocs:BuildRequires:	texlive-pdftex}
BuildRequires:	xorg-lib-libX11-devel >= 1.5
BuildRequires:	xorg-lib-libXext-devel
BuildRequires:	xorg-proto-dri2proto-devel >= 2.2
%endif
Requires:	xorg-lib-libX11 >= 1.5
# withdrawn (and never useful) Mesa drivers
Obsoletes:	libvdpau-driver-mesa-r300 < 10
Obsoletes:	libvdpau-driver-mesa-softpipe < 10
Conflicts:	xorg-driver-video-nvidia-libs < 1:190.42-2
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
VDPAU is the Video Decode and Presentation API for UNIX. It provides
an interface to video decode acceleration and presentation hardware
present in modern GPUs.

%description -l pl.UTF-8
VDPAU to skrót od Video Decode and Presentation API for UNIX.
Biblioteka ta dostarcza interfejs do akceleracji dekodowania oraz
prezentacji video obecnej we współczesnych procesorach graficznych.

%package devel
Summary:	Header files for vdpau library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki vdpau
Group:		Development/Libraries
%if "%{pld_release}" == "ac"
Requires:	XFree86-devel
%else
Requires:	xorg-lib-libX11-devel
%endif
Requires:	%{name} = %{version}-%{release}
Obsoletes:	libvdpau-static

%description devel
Header files for vdpau library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki vdpau.

%package apidocs
Summary:	vdpau API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki vdpau
Group:		Documentation
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API and internal documentation for vdpau library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki vdpau.

%prep
%setup -q

%build
%meson build \
	-Ddocumentation=%{__true_false apidocs}
%ninja_build -C build

%install
rm -rf $RPM_BUILD_ROOT

%ninja_install -C build

%{__rm} $RPM_BUILD_ROOT%{_libdir}/vdpau/libvdpau_trace.so

%if %{with apidocs}
mv $RPM_BUILD_ROOT%{_docdir}/{%{name}/html,%{name}-apidocs}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING
%attr(755,root,root) %{_libdir}/libvdpau.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libvdpau.so.1
%dir %{_libdir}/vdpau
%attr(755,root,root) %{_libdir}/vdpau/libvdpau_trace.so.*.*.*
%attr(755,root,root) %{_libdir}/vdpau/libvdpau_trace.so.1
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/vdpau_wrapper.cfg

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libvdpau.so
%{_includedir}/vdpau
%{_pkgconfigdir}/vdpau.pc

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_docdir}/%{name}-apidocs
%endif
%changelog
* Sat Sep 21 2019 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/libvdpau.git;a=log;h=master

* Sat Aug 31 2019 Jan Palus <atler@pld-linux.org> 2d08788
- really bump release

* Sat Aug 31 2019 Jan Palus <atler@pld-linux.org> da031fa
- BR: texlive-{dvips,latex}; rel 2

* Fri Aug 30 2019 Jakub Bogusz <qboosh@pld-linux.org> 7c0a16e
- ninja version for meson

* Thu Aug 29 2019 Jan Palus <atler@pld-linux.org> 9329254
- up to 1.3

* Thu Feb 28 2019 Jan Palus <atler@pld-linux.org> f99e596
- up to 1.2

* Sun Dec 16 2018 Jakub Bogusz <qboosh@pld-linux.org> 95def3d
- updated URLs

* Mon Aug 31 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 85cd242
- up to 1.1.1; fixes  CVE-2015-5198, CVE-2015-5199, and CVE-2015-5200

* Sun Mar 29 2015 Elan Ruusamäe <glen@delfi.ee> ce37ab1
- noarch apidocs

* Mon Mar 16 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 0b9fbed
- up to 1.1

* Mon Mar 09 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> ddb410c
- up to 1.0

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> d62d51f
- x32 rebuild
- release 2 (by relup.sh)

* Wed Dec 24 2014 Jan Rękorajski <baggins@pld-linux.org> e13cded
- link wirh libX11 due to missing _XEatData symbol

* Fri Dec 19 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> ad96775
- up to 0.9

* Tue Jul 01 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> b3bcc2a
- up to 0.8

* Fri Dec 06 2013 Jakub Bogusz <qboosh@pld-linux.org> ac5c2ad
- release 2

* Fri Dec 06 2013 Jakub Bogusz <qboosh@pld-linux.org> a704151
- Obsoletes for removed Mesa libvdpau drivers

* Mon Aug 05 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 0134418
- up to 0.7

* Mon May 20 2013 Elan Ruusamäe <glen@delfi.ee> 7aa7d9e
- rel 3

* Sun May 19 2013 Jakub Bogusz <qboosh@pld-linux.org> f757a1f
- fixed install time libX11 dependency

* Sun May 19 2013 Elan Ruusamäe <glen@delfi.ee> 36ded66
- R libx11 1.5

